Reference
=========

Reference documentation provides **information-oriented** technical descriptions.
This is where you find precise details about configuration options, commands, APIs, and specifications.

----

.. toctree::
   :maxdepth: 1

   configuration
   commands
   security
   models
   templates
   alternatives
